<?php

namespace Asadi\Result\Http\Controllers;
use Litepie\Result\Http\Requests\ResultRequest;
use Litepie\Result\Models\Result;

trait ResultWorkflow {
	
    /**
     * Workflow controller function for result.
     *
     * @param Model   $result
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(ResultRequest $request, Result $result, $step)
    {

        try {

            $result->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('result::result.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/result/result/' . $result->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/result/result/' . $result->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for result.
     *
     * @param Model   $result
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Result $result, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $result->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('result::result.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('result::admin.result.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('result::admin.result.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('result::admin.result.message', $data)->render();

        }

    }
}