<?php

namespace Asadi\Result\Workflow;

use Asadi\Result\Models\Result;
use Validator;

class ResultValidator
{

    /**
     * Determine if the given result is valid for complete status.
     *
     * @param Result $result
     *
     * @return bool / Validator
     */
    public function complete(Result $result)
    {
        return Validator::make($result->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given result is valid for verify status.
     *
     * @param Result $result
     *
     * @return bool / Validator
     */
    public function verify(Result $result)
    {
        return Validator::make($result->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given result is valid for approve status.
     *
     * @param Result $result
     *
     * @return bool / Validator
     */
    public function approve(Result $result)
    {
        return Validator::make($result->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given result is valid for publish status.
     *
     * @param Result $result
     *
     * @return bool / Validator
     */
    public function publish(Result $result)
    {
        return Validator::make($result->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given result is valid for archive status.
     *
     * @param Result $result
     *
     * @return bool / Validator
     */
    public function archive(Result $result)
    {
        return Validator::make($result->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given result is valid for unpublish status.
     *
     * @param Result $result
     *
     * @return bool / Validator
     */
    public function unpublish(Result $result)
    {
        return Validator::make($result->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
